# 仕様

## Topic

トピック名を設定

## Role

Pub or Sub

## Content-Length

メッセージの長さ

## Body

コンテンツ

## Environment

### LOGLEVEL

- DEBUG
- INFO(Default)

### SELECT_DB

- tinydb
- mongodb

### MONGO_HOST

mongodb://username:password@mongodb_host:27017
